@@ -1,6 +1,5 @@
-from .robotdashboard import RobotDashboard
-
-from fastapi import FastAPI, Body, Depends, HTTPException, status
+from fastapi_offline import FastAPIOffline
+from fastapi import Body, Depends, HTTPException, status
 from fastapi.responses import HTMLResponse, FileResponse
 from fastapi.security import HTTPBasic, HTTPBasicCredentials
 from pydantic import BaseModel
@@ -10,8 +9,10 @@ from os.path import join, abspath, dirname, exists
 from os import remove, mkdir, listdir
 from pathlib import Path
 from typing import List, Optional
-import secrets
+from secrets import compare_digest
 
+from .robotdashboard import RobotDashboard
+from .dependencies import DependencyProcessor
 from .version import __version__
 
 response_message_model_config = {
@@ -107,7 +108,7 @@ add_outputs_openapi_examples = {
         "summary": "When using an absolute folder path that contains output.xml's",
         "description": "When using an absolute folder path that contains output.xml's",
         "value": {
-            "output_path": "C:\\users\\docs\\prod-outputs",
+            "output_folder_path": "C:\\users\\docs\\prod-outputs",
             "output_tags": ["production-run"],
         },
     },
@@ -164,6 +165,7 @@ remove_log_model_config = {
 
 class ResponseMessage(BaseModel):
     """The response message model for Adding or Removing runs from the database"""
+
     success: str
     message: str
     console: str
@@ -176,6 +178,7 @@ class AdminJsonConfig(BaseModel):
 
 class GetOutput(BaseModel):
     """The response model that is returned when getting outputs"""
+
     run_start: str
     name: str
     alias: str
@@ -185,6 +188,7 @@ class GetOutput(BaseModel):
 
 class AddOutput(BaseModel):
     """The model that has to be provided when trying to add outputs to the database"""
+
     output_path: Optional[str] = None
     output_data: Optional[str] = None
     output_folder_path: Optional[str] = None
@@ -195,6 +199,7 @@ class AddOutput(BaseModel):
 
 class RemoveOutputs(BaseModel):
     """The model that has to be provided when trying to delete outputs from the database"""
+
     run_starts: Optional[List[str]] = None
     indexes: Optional[List[str]] = None
     aliases: Optional[List[str]] = None
@@ -204,6 +209,7 @@ class RemoveOutputs(BaseModel):
 
 class AddLog(BaseModel):
     """The model to add log files to the server"""
+
     log_data: str
     log_name: str
     model_config = add_log_model_config
@@ -211,6 +217,7 @@ class AddLog(BaseModel):
 
 class RemoveLog(BaseModel):
     """The model to remove log files from the server"""
+
     log_name: str
     model_config = remove_log_model_config
 
@@ -218,30 +225,55 @@ class RemoveLog(BaseModel):
 class ApiServer:
     """Robot Dashboard server implementation, this class handles the admin page and all functions related to the server"""
 
-    def __init__(self, server_host: str, server_port: int, server_user: str, server_pass: str):
+    def __init__(
+        self,
+        server_host: str,
+        server_port: int,
+        server_user: str,
+        server_pass: str,
+        offline_dependencies: bool,
+    ):
         """Init function that starts up the fastapi app and initializes all the vars and endpoints"""
-        self.app = FastAPI()
+        self.app = FastAPIOffline(title="Robot Framework Dashboard Server", version=__version__)
         self.security = HTTPBasic()
         self.robotdashboard: RobotDashboard
         self.server_host = server_host
         self.server_port = server_port
         self.server_user = server_user
         self.server_pass = server_pass
+        self.offline = offline_dependencies
         self.admin_json_config = "{}"
         self.log_dir = "robot_logs"
-        self.latest_log_dir: Path | None = None
+        self.latest_log_dir = None
 
         self._setup_routes()
         self._setup_catch_all_route()
 
+    def _get_admin_page(self):
+        admin_file = join(dirname(abspath(__file__)), "./templates", "admin.html")
+        admin_html = open(admin_file, "r").read()
+        admin_html = admin_html.replace('"placeholder_version"', __version__)
+
+        dependency_processor = DependencyProcessor(admin_page=True)
+        admin_html = admin_html.replace(
+            "<!-- placeholder_javascript -->", dependency_processor.get_js_block()
+        )
+        admin_html = admin_html.replace(
+            "<!-- placeholder_css -->", dependency_processor.get_css_block()
+        )
+        admin_html = admin_html.replace(
+            "<!-- placeholder_dependencies -->",
+            dependency_processor.get_dependencies_block(self.offline),
+        )
+        admin_html = admin_html.replace('"placeholder_version"', __version__)
+        return admin_html
+
     def _setup_routes(self):
         def authenticate(credentials: HTTPBasicCredentials = Depends(self.security)):
             if not self.server_user or not self.server_pass:
                 return "anonymous"
-
-            correct_username = secrets.compare_digest(credentials.username, self.server_user)
-            correct_password = secrets.compare_digest(credentials.password, self.server_pass)
-
+            correct_username = compare_digest(credentials.username, self.server_user)
+            correct_password = compare_digest(credentials.password, self.server_pass)
             if not (correct_username and correct_password):
                 raise HTTPException(
                     status_code=status.HTTP_401_UNAUTHORIZED,
@@ -251,21 +283,18 @@ class ApiServer:
             return credentials.username
 
         if not self.server_user or not self.server_pass:
+
             @self.app.get("/", response_class=HTMLResponse, include_in_schema=False)
             async def admin_page():
                 """Admin page endpoint function"""
-                admin_file = join(dirname(abspath(__file__)), "templates", "admin.html")
-                admin_html = open(admin_file, "r").read()
-                admin_html = admin_html.replace('"placeholder_version"', __version__)
-                return admin_html
+                return self._get_admin_page()
+
         else:
+
             @self.app.get("/", response_class=HTMLResponse, include_in_schema=False)
             async def admin_page(username: str = Depends(authenticate)):
                 """Admin page endpoint function"""
-                admin_file = join(dirname(abspath(__file__)), "templates", "admin.html")
-                admin_html = open(admin_file, "r").read()
-                admin_html = admin_html.replace('"placeholder_version"', __version__)
-                return admin_html
+                return self._get_admin_page()
 
         @self.app.get(
             "/dashboard", response_class=HTMLResponse, include_in_schema=False
@@ -390,12 +419,14 @@ class ApiServer:
                     )
                 if add_output.output_folder_path != None:
                     input = add_output.output_folder_path
-                    output_folder_path = [
-                        add_output.output_folder_path,
-                        output_tags,
+                    output_folder_paths = [
+                        [
+                            add_output.output_folder_path,
+                            output_tags,
+                        ]
                     ]
                     console = self.robotdashboard.process_outputs(
-                        output_folder_config=output_folder_path
+                        output_folder_configs=output_folder_paths
                     )
                 if add_output.output_data != None:
                     input = ""
@@ -533,11 +564,12 @@ class ApiServer:
                 "console": console,
             }
             return response
-        
+
     def _setup_catch_all_route(self):
         """Catch-all route for any resource after all other routes
         This will try to resolve based on screenshots that are relative to the log files
         If it doesn't find any matching file nothing will happen"""
+
         @self.app.get("/{full_path:path}", include_in_schema=False)
         async def catch_all(full_path: str):
             if self.latest_log_dir is None:
